<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'BR' => 'ब्राज़ील',
        'CN' => 'चीन',
        'DE' => 'जर्मनी',
        'FR' => 'फ़्रांस',
        'GB' => 'बरतानी',
        'IN' => 'भारत',
        'IT' => 'इटली',
        'JP' => 'जापान',
        'PK' => 'पाकिस्तान',
        'RU' => 'रशिया',
        'US' => 'अमेरिका',
    ],
];
